import 'package:flutter/material.dart' hide CheckboxListTile;
import 'package:photo/src/entity/options.dart';
import 'package:photo/src/provider/i18n_provider.dart';
import 'package:photo/src/ui/widget/check_tile_copy.dart';

abstract class CheckBoxBuilderDelegate {
  Widget buildCheckBox(
    BuildContext context,
    bool checked,
    int index,
    Options options,
    I18nProvider i18nProvider,
  );
}

class DefaultCheckBoxBuilderDelegate extends CheckBoxBuilderDelegate {
  Color activeColor;
  Color checkColor;
  Color unselectedColor;

  DefaultCheckBoxBuilderDelegate({
    this.activeColor,
    this.checkColor,
    this.unselectedColor,
  });

  @override
  Widget buildCheckBox(
    BuildContext context,
    bool checked,
    int index,
    Options options,
    I18nProvider i18nProvider,
  ) {
    return Theme(
      data: Theme.of(context).copyWith(
          unselectedWidgetColor:
              unselectedColor ?? options.theme.unselectedColor),
      child: Container(
        child: Row(
          children: [
            SizedBox(
              width: 20,
              height: 20,
              child: Checkbox(
                value: checked,
                onChanged: (bool check) {},
                activeColor: activeColor ?? options.theme.primaryColor,
                checkColor: checkColor ?? options.theme.onPrimaryColor,
              ),
            ),
            SizedBox(
              width: 6,
            ),
            Text(
              i18nProvider.getSelectedOptionsText(options),
              textAlign: TextAlign.start,
              style: options.theme.textStyle,
            ),
          ],
        ),
      ),
    );
  }
}

class RadioCheckBoxBuilderDelegate {
  Color activeColor;
  Color unselectedColor;

  RadioCheckBoxBuilderDelegate({
    this.activeColor,
    this.unselectedColor,
  });

  Widget buildCheckBox(
    BuildContext context,
    bool checked,
    Options options,
    I18nProvider i18nProvider,
  ) {
    return Theme(
      data: Theme.of(context).copyWith(
          unselectedWidgetColor:
              unselectedColor ?? options.theme.unselectedColor),
      child: Container(
        child: Row(
          children: [
            SizedBox(
              width: 20,
              height: 20,
              child: Radio(
                value: true,
                groupValue: checked,
                onChanged: (bool check) {},
                activeColor: activeColor ?? options.theme.primaryColor,
              ),
            ),
            SizedBox(
              width: 6,
            ),
            Text(
              i18nProvider.getFullImageText(options),
              textAlign: TextAlign.start,
              style: options.theme.textStyle,
            ),
          ],
        ),
      ),
    );
  }
}
