import 'package:flutter/material.dart';

class PhotoTheme {
  final Color primaryColor;
  final Color onPrimaryColor;
  final Color surfaceColor;
  final Color onSurfaceColor;
  final Color backgroundColor;
  final Color onBackgroundColor;
  final Color dividerColor;
  final Color disableColor;
  final Color unselectedColor;
  final TextStyle textStyle;

  factory PhotoTheme.fallback(BuildContext context) {
    final theme = Theme.of(context);
    return PhotoTheme._(
      primaryColor: theme.colorScheme?.primary ?? Color(0xFF01AAFF),
      onPrimaryColor: theme.colorScheme?.onPrimary ?? Color(0xFFFFFFFF),
      surfaceColor: theme.colorScheme?.surface ?? (theme.brightness == Brightness.light ? Color(0xFFFFFFFF) : Color(0xFF282828)),
      onSurfaceColor: theme.colorScheme?.onSurface ?? (theme.brightness == Brightness.light ? Color(0xFF8C8C8C) : Color(0xFF696969)),
      backgroundColor: theme.colorScheme?.background ?? (theme.brightness == Brightness.light ? Color(0xFFF8F8F8) : Color(0xFF1F1F1F)),
      onBackgroundColor: theme.colorScheme?.onBackground ?? Color(0xFF8C8C8C),
      dividerColor: theme.dividerColor ?? (theme.brightness == Brightness.light ? Color(0xFFF2F2F2) : Color(0xFF3B3B3B)),
      disableColor: theme.disabledColor,
      unselectedColor: theme.unselectedWidgetColor ?? (theme.brightness == Brightness.light ? Color(0xFFBFBFBF) : Color(0xFF696969)),
      textStyle: TextStyle(
        color: theme.brightness == Brightness.light ? Color(0xFF595959) : Color(0xFFA8A8A8),
        fontSize: 16,
        fontWeight: FontWeight.w400,
      ), //theme.textTheme?.subtitle2 ?? 
    );
  }

  PhotoTheme._({
    @required this.primaryColor,
    @required this.onPrimaryColor,
    @required this.surfaceColor,
    @required this.onSurfaceColor,
    @required this.backgroundColor,
    @required this.onBackgroundColor,
    @required this.dividerColor,
    @required this.disableColor,
    @required this.unselectedColor,
    @required this.textStyle,
  });

  PhotoTheme copyWith({
    Color primaryColor,
    Color onPrimaryColor,
    Color surfaceColor,
    Color onSurfaceColor,
    Color backgroundColor,
    Color onBackgroundColor,
    Color dividerColor,
    Color disableColor,
    Color unselectedColor,
    TextStyle textStyle,
  }) {
    return PhotoTheme._(
      primaryColor: primaryColor ?? this.primaryColor,
      onPrimaryColor: onPrimaryColor ?? this.onPrimaryColor,
      surfaceColor: surfaceColor ?? this.surfaceColor,
      onSurfaceColor: onSurfaceColor ?? this.onSurfaceColor,
      backgroundColor: backgroundColor ?? this.backgroundColor,
      onBackgroundColor: onBackgroundColor ?? this.onBackgroundColor,
      dividerColor: dividerColor ?? this.dividerColor,
      disableColor: disableColor ?? this.disableColor,
      unselectedColor: unselectedColor ?? this.unselectedColor,
      textStyle: textStyle ?? this.textStyle,
    );
  }
}
