import 'package:flutter/material.dart';
import 'package:photo/src/entity/options.dart';
import 'package:photo/src/provider/i18n_provider.dart';
import 'package:photo_manager/photo_manager.dart';

class ChangeGalleryDialog extends StatefulWidget {

  final ValueChanged<AssetPathEntity> onGalleryChange;
  final List<AssetPathEntity> galleryList;
  final I18nProvider i18n;
  final Options options;
  final AssetPathEntity current;

  const ChangeGalleryDialog({
    Key key,
    this.onGalleryChange,
    this.galleryList,
    this.i18n,
    this.options,
    this.current,
  }) : super(key: key);

  @override
  _ChangeGalleryDialogState createState() => _ChangeGalleryDialogState();
}

class _ChangeGalleryDialogState extends State<ChangeGalleryDialog> {
      
  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.symmetric(horizontal: 16),
      child: MediaQuery.removePadding(
        context: context,
        removeTop: true,
        removeLeft: true,
        child: ListView.builder(
          itemBuilder: _buildItem,
          itemCount: widget.galleryList.length,
        ),
      ),
    );
  }

  Widget _buildItem(BuildContext context, int index) {
    var entity = widget.galleryList[index];
    String text;

    if (entity.isAll) {
      text = widget.i18n?.getAllGalleryText(widget.options);
    }

    text = text ?? entity.name;

    return FlatButton(
      padding: EdgeInsets.zero,
      child: Container(
        padding: EdgeInsets.symmetric(vertical: 12),
        decoration: BoxDecoration(
          border: Border(
            top: index == 0 ? BorderSide.none : BorderSide(color: widget.options.theme.dividerColor, width: 1),
          ),
        ),
        child: Row(
          children: [
            // ImageItem(),
            Container(
              width: 40,
              height: 40,
              color: Colors.black,
            ),
            SizedBox(width: 16,),
            Expanded(
              child: Row(
                children: [
                  Expanded(
                    child: Row(
                      children: <Widget>[
                        Text('$text ', style: widget.options.theme.textStyle,),
                        Text('(${entity.assetCount})', style: widget.options.theme.textStyle.copyWith(fontSize: 14),),
                      ],
                    ),
                  ),
                  if (widget.current.id == entity.id)
                  Icon(
                    Icons.check_circle,
                    size: 20,
                    color: widget.options.theme.primaryColor,
                  ),
                  // RichText(
                  //   text: TextSpan(
                  //     text: '$text ',
                  //     style: widget.options.theme.textStyle.copyWith(
                  //       height: 1.4,
                  //     ),
                  //     children: [
                  //       TextSpan(
                  //         text: '(${entity.assetCount})',
                  //         style: widget.options.theme.textStyle.copyWith(
                  //           fontSize: 14,
                  //           height: 1.6,
                  //         ),
                  //       )
                  //     ]
                  //   ),
                  // )
                ],
              )
            ),
          ],
        ),
      ),
      onPressed: () {
        widget.onGalleryChange?.call(entity);
      },
    );
  }
}
