part of '../photo_main_page.dart';

class _BottomWidget extends StatefulWidget {

  final Options options;

  final I18nProvider provider;

  final SelectedProvider selectedProvider;

  final GalleryListProvider galleryListProvider;
  final VoidCallback onTapPreview;
  final VoidCallback onTapSure;

  const _BottomWidget({
    Key key,
    this.options,
    this.provider,
    this.selectedProvider,
    this.galleryListProvider,
    this.onTapPreview,
    this.onTapSure,
  }) : super(key: key);

  @override
  __BottomWidgetState createState() => __BottomWidgetState();
}

class __BottomWidgetState extends State<_BottomWidget> {
  Options get options => widget.options;

  I18nProvider get i18nProvider => widget.provider;

  SelectedProvider get selectedProvider => widget.selectedProvider;

  bool get isFullImage => selectedProvider.isFullImage;

  @override
  Widget build(BuildContext context) {
    return DefaultTextStyle(
      style: options.theme.textStyle,
      child: Container(
        color: options.theme.surfaceColor,
        padding: EdgeInsets.symmetric(horizontal: 24),
        child: SafeArea(
          bottom: true,
          top: false,
          child: Container(
            height: 50.0,
            child: Row(
              children: <Widget>[
                GestureDetector(
                  onTap: widget.onTapPreview,
                  child: Container(
                    alignment: Alignment.center,
                    height: 30.0,
                    child: Text(
                      i18nProvider.getPreviewText(
                          options, widget.selectedProvider),
                      style: options.theme.textStyle.copyWith(
                        color: widget.onTapPreview == null ? options.theme.disableColor : options.theme.textStyle.color,
                      ),
                    ),
                  ),
                ),
                SizedBox(width: 24,),
                Expanded(
                  child: Container(
                    child: Stack(
                      children: <Widget>[
                        IgnorePointer(
                          child: RadioCheckBoxBuilderDelegate().buildCheckBox(
                            context,
                            isFullImage,
                            options,
                            i18nProvider,
                          ),
                        ),
                        Positioned(
                          top: 0.0,
                          bottom: 0.0,
                          left: 0.0,
                          right: 0.0,
                          child: GestureDetector(
                            onTap: () {
                              selectedProvider.isFullImage = !isFullImage;
                              setState(() {});
                            },
                            behavior: HitTestBehavior.translucent,
                            child: Container(),
                          ),
                        ),
                      ],
                    ),
                  ),
                ),
                SizedBox(
                  width: 110,
                  height: 36.0,
                  child: FlatButton(
                    onPressed: widget.onTapSure,
                    splashColor: Colors.transparent,
                    color: options.theme.primaryColor,
                    textColor: options.theme.onPrimaryColor,
                    disabledColor: options.theme.disableColor,
                    disabledTextColor: options.theme.disableColor,
                    shape: StadiumBorder(),
                    padding: EdgeInsets.zero,
                    child: Container(
                      alignment: Alignment.center,
                      child: Text(
                        i18nProvider.getSureText(options, selectedProvider.selectedList.length),
                        style: TextStyle(
                          fontSize: options.theme.textStyle.fontSize - 2,
                          fontWeight: options.theme.textStyle.fontWeight,
                        ),
                      ),
                    ),
                  ),
                ),
              ],
            ),
          ),
        ),
      ),
    );
  }
}
